==> nextcloud-28.0.5.tar.bz2: nextcloud/apps/weather_status/l10n/lt_LT.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Nežinomas adresas",
    "No result." : "Nėra rezultatų.",
    "Malformed JSON data." : "Netaisyklingi JSON duomenys.",
    "Error" : "Klaida",
    "Weather status" : "Orų būsena",
    "Weather status in your dashboard" : "Orų būsena jūsų skydelyje",
    "Detect location" : "Aptikti vietą",
    "Set custom address" : "Nustatyti tinkintą adresą",
    "Favorites" : "Mėgstamos",
    "{temperature} {unit} clear sky later today" : "Šiandien vėliau bus {temperature} {unit}, giedra",
    "{temperature} {unit} clear sky" : "{temperature} {unit}, giedra",
    "{temperature} {unit} cloudy later today" : "Šiandien vėliau bus {temperature} {unit}, debesuota",
    "{temperature} {unit} cloudy" : "{temperature} {unit}, debesuota",
    "{temperature} {unit} fair weather later today" : "Šiandien vėliau bus {temperature} {unit}, mažai debesuota",
    "{temperature} {unit} fair weather" : "{temperature} {unit}, mažai debesuota",
    "{temperature} {unit} partly cloudy later today" : "Šiandien vėliau bus {temperature} {unit}, su pragiedruliais",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit}, su pragiedruliais",
    "{temperature} {unit} foggy later today" : "Šiandien vėliau bus {temperature} {unit}, ūkanota",
    "{temperature} {unit} foggy" : "{temperature} {unit}, ūkanota",
    "{temperature} {unit} light rainfall later today" : "Šiandien vėliau bus {temperature} {unit}, silpnas lietus",
    "{temperature} {unit} light rainfall" : "{temperature} {unit}, silpnas lietus",
    "{temperature} {unit} rainfall later today" : "Šiandien vėliau bus {temperature} {unit}, lietus",
    "{temperature} {unit} rainfall" : "{temperature} {unit}, lietus",
    "{temperature} {unit} heavy rainfall later today" : "Šiandien vėliau bus {temperature} {unit}, stiprus lietus",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit}, stiprus lietus",
    "{temperature} {unit} rainfall showers later today" : "Šiandien vėliau bus {temperature} {unit}, liūtys",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit}, liūtys",
    "{temperature} {unit} light rainfall showers later today" : "Šiandien vėliau bus {temperature} {unit}, silpnos liūtys",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit}, silpnos liūtys",
    "{temperature} {unit} heavy rainfall showers later today" : "Šiandien vėliau bus {temperature} {unit}, stiprios liūtys",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit}, stiprios liūtys",
    "More weather for {adr}" : "Daugiau orų ties {adr}",
    "Loading weather" : "Įkeliami orai",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add as favorite" : "Pridėti kaip mėgstamą",
    "You are not logged in." : "Jūs nesate prisijungę.",
    "There was an error getting the weather status information." : "Gaunant orų būsenos informaciją, įvyko klaida.",
    "No weather information found" : "Nerasta jokios informacijos apie orus",
    "Location not found" : "Vieta nerasta",
    "There was an error setting the location address." : "Nustatant vietos adresą, įvyko klaida.",
    "There was an error setting the location." : "Nustatant vietą, įvyko klaida.",
    "There was an error saving the mode." : "Įrašant veikseną, įvyko klaida.",
    "There was an error using personal address." : "Naudojant asmeninį adresą, įvyko klaida.",
    "Set location for weather" : "Nustatyti vietą orams",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Orų būsena, integruota į skydelio programėlę.\n    Naudotojo vieta gali būti nustatyta automatiškai arba apibrėžta rankiniu būdu. Tuomet yra rodoma 6 valandų orų prognozė.\n    Ši būsena taip pat gali būti integruota kitose vietose, kaip, pavyzdžiui, kalendoriaus programėlėje."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-29.0.12.tar.bz2: nextcloud/apps/weather_status/l10n/lt_LT.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Nežinomas adresas",
    "No result." : "Nėra rezultatų.",
    "Malformed JSON data." : "Netaisyklingi JSON duomenys.",
    "Error" : "Klaida",
    "Weather status" : "Orų būsena",
    "Weather status in your dashboard" : "Orų būsena jūsų skydelyje",
    "Detect location" : "Aptikti vietą",
    "Set custom address" : "Nustatyti tinkintą adresą",
    "Favorites" : "Mėgstamos",
    "{temperature} {unit} clear sky later today" : "Šiandien vėliau bus {temperature} {unit}, giedra",
    "{temperature} {unit} clear sky" : "{temperature} {unit}, giedra",
    "{temperature} {unit} cloudy later today" : "Šiandien vėliau bus {temperature} {unit}, debesuota",
    "{temperature} {unit} cloudy" : "{temperature} {unit}, debesuota",
    "{temperature} {unit} snow" : "{temperature} {unit}, sniegas",
    "{temperature} {unit} fair weather later today" : "Šiandien vėliau bus {temperature} {unit}, mažai debesuota",
    "{temperature} {unit} fair weather" : "{temperature} {unit}, mažai debesuota",
    "{temperature} {unit} partly cloudy later today" : "Šiandien vėliau bus {temperature} {unit}, su pragiedruliais",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit}, su pragiedruliais",
    "{temperature} {unit} foggy later today" : "Šiandien vėliau bus {temperature} {unit}, ūkanota",
    "{temperature} {unit} foggy" : "{temperature} {unit}, ūkanota",
    "{temperature} {unit} light rainfall later today" : "Šiandien vėliau bus {temperature} {unit}, silpnas lietus",
    "{temperature} {unit} light rainfall" : "{temperature} {unit}, silpnas lietus",
    "{temperature} {unit} rainfall later today" : "Šiandien vėliau bus {temperature} {unit}, lietus",
    "{temperature} {unit} rainfall" : "{temperature} {unit}, lietus",
    "{temperature} {unit} heavy rainfall later today" : "Šiandien vėliau bus {temperature} {unit}, stiprus lietus",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit}, stiprus lietus",
    "{temperature} {unit} rainfall showers later today" : "Šiandien vėliau bus {temperature} {unit}, liūtys",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit}, liūtys",
    "{temperature} {unit} light rainfall showers later today" : "Šiandien vėliau bus {temperature} {unit}, silpnos liūtys",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit}, silpnos liūtys",
    "{temperature} {unit} heavy rainfall showers later today" : "Šiandien vėliau bus {temperature} {unit}, stiprios liūtys",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit}, stiprios liūtys",
    "More weather for {adr}" : "Daugiau orų ties {adr}",
    "Loading weather" : "Įkeliami orai",
    "Set location for weather" : "Nustatyti vietą orams",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add as favorite" : "Pridėti kaip mėgstamą",
    "You are not logged in." : "Jūs nesate prisijungę.",
    "There was an error getting the weather status information." : "Gaunant orų būsenos informaciją, įvyko klaida.",
    "No weather information found" : "Nerasta jokios informacijos apie orus",
    "Location not found" : "Vieta nerasta",
    "There was an error setting the location address." : "Nustatant vietos adresą, įvyko klaida.",
    "There was an error setting the location." : "Nustatant vietą, įvyko klaida.",
    "There was an error saving the mode." : "Įrašant veikseną, įvyko klaida.",
    "There was an error using personal address." : "Naudojant asmeninį adresą, įvyko klaida.",
    "Unknown weather code" : "Nežinomas orų kodas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
